pub fn load_schemas(path: &Path) -> Result<Vec<ContentSchema>>Expand description
Loads all content schemas from a content.schema.toml file.
Returns an empty Vec if the file does not exist — schemas are
opt-in.
pub fn load_schemas(path: &Path) -> Result<Vec<ContentSchema>>Loads all content schemas from a content.schema.toml file.
Returns an empty Vec if the file does not exist — schemas are
opt-in.